@@ -80,12 +80,15 @@ class RepoRun:
         work_dir = self.git.prepare(repo)
         tpl_mapping = create_template_mapping(repo)
         pr = source.PullRequest(
+            matcher.auto_merge,
+            matcher.merge_once,
             matcher.name,
             self.opts.config.pr_title_prefix,
             self.opts.config.pr_title_body.format(matcher_name=matcher.name),
             self.opts.config.pr_title_suffix,
             matcher.pr_body,
             matcher.pr_title,
+            auto_merge_after=matcher.auto_merge_after,
         )
         apply_actions(pkgs, repo, matcher, tpl_mapping, work_dir)
         has_changes = False
@@ -96,6 +99,26 @@ class RepoRun:
         else:
             log.info("No changes after applying actions", repo=str(repo))
 
+        if (
+            self.git.has_changes_base(base_branch=repo.base_branch, repo_dir=work_dir)
+            is False
+            and repo.is_pr_open(pr_identifier) is True
+        ):
+            if self.opts.config.dry_run:
+                log.warn(
+                    "DRY RUN: Closing pull request because base branch contains all changes"
+                )
+            else:
+                log.info(
+                    "Closing pull request because base branch contains all changes",
+                    repo=str(repo),
+                )
+                repo.close_pull_request(
+                    "Everything up-to-date. Closing.", pr_identifier
+                )
+
+            return
+
         # Combining self.git.needs_push and has_changes avoids an unnecessary push of the
         # branch if the remote branch does not exist.
         needs_push = self.git.needs_push(work_dir) and has_changes
@@ -115,6 +138,8 @@ class RepoRun:
                 log.info("Create pull request", repo=str(repo))
                 repo.create_pull_request(self.git.branch_name, pr)
 
+            return
+
         if (
             matcher.auto_merge is True
             and needs_push is False
@@ -139,6 +164,11 @@ class RepoRun:
                 log.info("Merge pull request", repo=str(repo))
                 repo.merge_pull_request(pr_identifier)
 
+            return
+
+        if pr_identifier is not None and repo.is_pr_open(pr_identifier) is True:
+            repo.update_pull_request(pr_identifier, pr)
+
 
 def apply_actions(
     pkgs: list[package.Package],
