@@ -1,20 +1,28 @@
 import datetime
 import urllib.parse
-from typing import Any, TextIO, Union
+from typing import Any, Optional, TextIO, Union
+
+import humanize
 
 
 class PullRequest:
     def __init__(
         self,
+        auto_merge: bool,
+        merge_once: bool,
         run_name: str,
         title_prefix: str,
         title_body: str,
         title_suffix: str,
-        custom_body="",
-        custom_title="",
+        custom_body: str = "",
+        custom_title: str = "",
+        auto_merge_after: Optional[datetime.timedelta] = None,
     ):
+        self.auto_merge = auto_merge
+        self.auto_merge_after = auto_merge_after
         self.custom_body = custom_body
         self.custom_title = custom_title
+        self.merge_once = merge_once
         self.run_name = run_name
         self.title_prefix = title_prefix
         self.title_body = title_body
@@ -27,12 +35,21 @@ class PullRequest:
         :param other: Other PullRequest
         :return: bool
         """
+        if self.auto_merge != getattr(other, "auto_merge"):
+            return False
+
+        if self.auto_merge_after != getattr(other, "auto_merge_after"):
+            return False
+
         if self.custom_body != getattr(other, "custom_body"):
             return False
 
         if self.custom_title != getattr(other, "custom_title"):
             return False
 
+        if self.merge_once != getattr(other, "merge_once"):
+            return False
+
         if self.run_name != getattr(other, "run_name"):
             return False
 
@@ -49,22 +66,40 @@ class PullRequest:
 
     @property
     def body(self) -> str:
-        if self.custom_body != "":
-            return self.custom_body
+        if self.custom_body == "":
+            body = f"Apply changes from Run {self.run_name}\n"
+        else:
+            body = self.custom_body
+            body += "\n"
 
-        return f"""Apply changes from Run {self.run_name}
+        body += "\n---\n\n"
 
+        body += "**Automerge:** "
+        if self.auto_merge is True:
+            if self.auto_merge_after is None:
+                body += "Enabled. rcmt merges this automatically on its next run and if all checks have passed.\n"
+            else:
+                after = humanize.naturaldelta(self.auto_merge_after)
+                body += f"Enabled. rcmt automatically merges this in {after} and if all checks have passed.\n"
+        else:
+            body += "Disabled. Merge this manually.\n"
+
+        if self.merge_once is True:
+            body += "**Ignore:** Close this PR and it will not be recreated again.\n"
+
+        body += """
 ---
 
-_This pull request has been created by [rcmt](https://rcmt.readthedocs.io/)._
-"""
+_This pull request has been created by [rcmt](https://rcmt.readthedocs.io/)._"""
+
+        return body
 
     @property
     def title(self) -> str:
         if self.custom_title != "":
             return self.custom_title
 
-        return f"{self.title_prefix} {self.title_body} {self.title_suffix}"
+        return f"{self.title_prefix} {self.title_body} {self.title_suffix}".strip()
 
 
 class Repository:
@@ -92,6 +127,19 @@ class Repository:
         """
         raise NotImplementedError("class does not implement Repository.clone_url()")
 
+    def close_pull_request(self, message: str, pr: Any) -> None:
+        """
+        Closes a pull request and adds a comment that explains why the pull request has
+        been closed.
+
+        :param message: Message to post as a comment.
+        :param pr: The pull request.
+        :rtype: None
+        """
+        raise NotImplementedError(
+            "class does not implement Repository.close_pull_request()"
+        )
+
     def create_pull_request(self, branch: str, pr: PullRequest) -> None:
         """
         Creates a pull request for the given branch.
@@ -228,6 +276,21 @@ class Repository:
         """
         raise NotImplementedError("class does not implement Repository.source()")
 
+    def update_pull_request(self, pr: Any, pr_data: PullRequest) -> None:
+        """
+        Updates the title and body of a pull request.
+
+        To reduce calls to the API, the implementation of this function should check if
+        title or body have changed and only update the pull request if necessary.
+
+        :param pr: Data to identify the pull request as returned by find_pull_request.
+        :param pr_data: Data of the pull request that rcmt wants to create/update.
+        :rtype: None
+        """
+        raise NotImplementedError(
+            "class does not implement Repository.update_pull_request()"
+        )
+
 
 class Base:
     """
